==> winter-1.4.0.tar.gz: winter-1.4.0/winter/schema/query_parameters_inspector.py <==
import inspect
from typing import List

import docstring_parser
from drf_yasg import openapi

from .controller_method_inspector import ControllerMethodInspector
from .generation import get_argument_type_info
from .. import type_utils
from ..core import ComponentMethod
from ..query_parameter import get_query_param_mapping


class QueryParametersInspector(ControllerMethodInspector):

    def inspect_parameters(self, method: ComponentMethod) -> List[openapi.Parameter]:
        docstring = docstring_parser.parse(method.func.__doc__)
        params_docs = {param_doc.arg_name: param_doc for param_doc in docstring.params}

        parameters = []

        for argument in method.arguments:
            query_parameter_name = get_query_param_mapping(argument.method, argument.name)
            if not query_parameter_name:
                continue
            param_doc = params_docs.get(query_parameter_name)
            description = param_doc.description if param_doc else ''
            default_params = {}
            default = argument.parameter.default
            if default is not inspect.Parameter.empty:
                default_params['default'] = default
            required = default is inspect.Parameter.empty and not type_utils.is_optional(argument.type_)
            type_info = get_argument_type_info(argument)
            if type_info is None:
                type_info = {'type': openapi.TYPE_STRING}
                description += ' (Note: parameter type can be wrong)'
            parameter = openapi.Parameter(
                name=query_parameter_name,
                description=description,
                required=required,
                in_=openapi.IN_QUERY,
                **type_info,
                **default_params,
            )
            parameters.append(parameter)

        return parameters

==> winter-1.4.1.tar.gz: winter-1.4.1/winter/schema/query_parameters_inspector.py <==
import inspect
from typing import List

import docstring_parser
from drf_yasg import openapi

from .generation import get_argument_type_info
from .method_arguments_inspector import MethodArgumentsInspector
from .utils import update_doc_with_invalid_hype_hint
from .. import type_utils
from ..core import ComponentMethod
from ..query_parameter import get_query_param_mapping


class QueryParametersInspector(MethodArgumentsInspector):

    def inspect_parameters(self, method: ComponentMethod) -> List[openapi.Parameter]:
        docstring = docstring_parser.parse(method.func.__doc__)
        params_docs = {param_doc.arg_name: param_doc for param_doc in docstring.params}

        parameters = []

        for argument in method.arguments:
            query_parameter_name = get_query_param_mapping(argument.method, argument.name)

            if query_parameter_name is None:
                continue

            param_doc = params_docs.get(query_parameter_name)
            description = param_doc.description if param_doc else ''
            default_params = {}
            default = argument.parameter.default
            if default is not inspect.Parameter.empty:
                default_params['default'] = default
            required = default is inspect.Parameter.empty and not type_utils.is_optional(argument.type_)
            type_info = get_argument_type_info(argument)

            if type_info is None:
                type_info_data = {'type': openapi.TYPE_STRING}
                description = update_doc_with_invalid_hype_hint(description)
            else:
                type_info_data = type_info.as_dict()

            parameter = openapi.Parameter(
                name=query_parameter_name,
                description=description,
                required=required,
                in_=openapi.IN_QUERY,
                **type_info_data,
                **default_params,
            )
            parameters.append(parameter)

        return parameters
